bug-gnu-emacs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

bug#10421: Don't use the abbreviation "win" to refer to Windows.


From: Paul Eggert
Subject: bug#10421: Don't use the abbreviation "win" to refer to Windows.
Date: Mon, 02 Jan 2012 00:51:40 -0800
User-agent: Mozilla/5.0 (X11; Linux i686; rv:8.0) Gecko/20111124 Thunderbird/8.0

On 01/02/12 00:29, Eli Zaretskii wrote:
> These two are wrong: "Win32 API" is the proper name of the API.
> There's no such thing as "w32 API".

Thanks for catching that.  The Wikipedia entry
<http://en.wikipedia.org/wiki/Windows_API>
says that "Windows API" is a better name for that API,
and "Windows API" avoids the problem of the "win" acronym,
so here's a further patch to do that and to do some other
minor housekeeping such as a Bug#.  For convenience I'm
attaching a compressed version of the entire revised patch.

=== modified file 'leim/makefile.w32-in'
--- leim/makefile.w32-in        2011-08-20 22:19:53 +0000
+++ leim/makefile.w32-in        2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-# -*- Makefile -*- for leim subdirectory in GNU Emacs on the Microsoft W32 API.
+# -*- Makefile -*- for leim subdirectory in GNU Emacs on the Microsoft Windows 
API.
 
 # Copyright (C) 2000-2011  Free Software Foundation, Inc.
 # Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,

=== modified file 'lib-src/makefile.w32-in'
--- lib-src/makefile.w32-in     2011-11-27 18:52:53 +0000
+++ lib-src/makefile.w32-in     2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-#  -*- Makefile -*- for GNU Emacs on the Microsoft W32 API.
+#  -*- Makefile -*- for GNU Emacs on the Microsoft Windows API.
 # Copyright (C) 2000-2011 Free Software Foundation, Inc.
 
 # This file is part of GNU Emacs.

=== modified file 'lib/makefile.w32-in'
--- lib/makefile.w32-in 2011-11-05 11:34:56 +0000
+++ lib/makefile.w32-in 2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-# -*- Makefile -*- for GNU Emacs on the Microsoft W32 API.
+# -*- Makefile -*- for GNU Emacs on the Microsoft Windows API.
 # Copyright (C) 2011 Free Software Foundation, Inc.
 
 # This file is part of GNU Emacs.

=== modified file 'lisp/dos-w32.el'
--- lisp/dos-w32.el     2012-01-02 06:41:42 +0000
+++ lisp/dos-w32.el     2012-01-02 08:44:52 +0000
@@ -356,7 +356,7 @@
          (apply 'call-process lpr-prog nil errbuf nil rest))
         ;; Run command.com to access printer port on Windows 9x, unless
         ;; we are supposed to append to an existing (non-empty) file,
-        ;; to work around a bug in Windows 9x that prevents w32
+        ;; to work around a bug in Windows 9x that prevents Windows
         ;; programs from accessing LPT ports reliably.
         ((and (eq system-type 'windows-nt)
               (getenv "winbootdir")

=== modified file 'lisp/makefile.w32-in'
--- lisp/makefile.w32-in        2011-12-10 12:49:33 +0000
+++ lisp/makefile.w32-in        2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-# -*- Makefile -*- for GNU Emacs on the Microsoft W32 API.
+# -*- Makefile -*- for GNU Emacs on the Microsoft Windows API.
 # Copyright (C) 2000-2011  Free Software Foundation, Inc.
 
 # This file is part of GNU Emacs.

=== modified file 'lisp/org/ChangeLog'
--- lisp/org/ChangeLog  2012-01-02 06:41:42 +0000
+++ lisp/org/ChangeLog  2012-01-02 08:44:52 +0000
@@ -1,6 +1,6 @@
 2012-01-02  Paul Eggert  <eggert@cs.ucla.edu>
 
-       Don't use the abbreviation "win" to refer to Windows.
+       Don't use the abbreviation "win" to refer to Windows (Bug#10421).
        * ob-lilypond.el (ly-w32-ly-path): Rename from ly-win32-ly-path.
        (ly-w32-pdf-path): Rename from ly-win32-pdf-path.
        (ly-w32-midi-path): Rename from ly-win32-midi-path.

=== modified file 'nt/ChangeLog'
--- nt/ChangeLog        2012-01-02 06:41:42 +0000
+++ nt/ChangeLog        2012-01-02 08:44:52 +0000
@@ -648,7 +648,7 @@
 
 2008-04-04  Jason Rumney  <jasonr@gnu.org>
 
-       * INSTALL: Update W32 API requirements.
+       * INSTALL: Update Windows API requirements.
 
 2008-04-03  Jason Rumney  <jasonr@gnu.org>
 

=== modified file 'nt/INSTALL'
--- nt/INSTALL  2011-11-25 13:26:30 +0000
+++ nt/INSTALL  2012-01-02 08:44:52 +0000
@@ -115,7 +115,7 @@
 
   To compile Emacs, you will need either Microsoft Visual C++ 2.0, or
   later and nmake, or a Windows port of GCC 2.95 or later with MinGW
-  and W32 API support and a port of GNU Make.  You can use the Cygwin
+  and Windows API support and a port of GNU Make.  You can use the Cygwin
   ports of GCC, but Emacs requires the MinGW headers and libraries to
   build (latest versions of the Cygwin toolkit, at least since v1.3.3,
   include the MinGW headers and libraries as an integral part).
@@ -540,7 +540,7 @@
 * Trouble-shooting
 
   The main problems that are likely to be encountered when building
-  Emacs stem from using an old version of GCC, or old MinGW or W32 API
+  Emacs stem from using an old version of GCC, or old MinGW or Windows API
   headers.  Additionally, Cygwin ports of GNU make may require the Emacs
   source tree to be mounted with text!=binary, because the makefiles
   generated by configure.bat necessarily use DOS line endings.  Also,
@@ -552,7 +552,7 @@
   2.95 or later is needed, because that is when the Windows port gained
   sufficient support for anonymous structs and unions to cope with some
   definitions from winnt.h that are used by addsection.c.
-  Older versions of the W32 API headers that come with Cygwin and MinGW
+  Older versions of the Windows API headers that come with Cygwin and MinGW
   may be missing some definitions required by Emacs, or broken in other
   ways.  In particular, uniscribe APIs were added to MinGW CVS only on
   2006-03-26, so releases from before then cannot be used.

=== modified file 'nt/configure.bat'
--- nt/configure.bat    2011-11-25 13:26:30 +0000
+++ nt/configure.bat    2012-01-02 08:44:52 +0000
@@ -23,7 +23,7 @@
 rem

 rem   + MS Windows 95, NT or later

 rem   + either MSVC 2.x or later, or gcc-2.95 or later (with GNU make 3.75

-rem     or later) and the Mingw32 and W32 API headers and libraries.

+rem     or later) and the Mingw32 and Windows API headers and libraries.

 rem   + Visual Studio 2005 is not supported at this time.

 rem

 rem For reference, here is a list of which builds of GNU make are known to

@@ -416,7 +416,7 @@
 rem   of w32api-xxx.zip from Anders Norlander since 1999-11-18 at least.

 rem   Beginning with Emacs 23, we need usp10.h.

 rem

-echo Checking whether W32 API headers are too old...

+echo Checking whether Windows API headers are too old...

 echo #include "windows.h" >junk.c

 echo #include "usp10.h" >>junk.c

 echo test(PIMAGE_NT_HEADERS pHeader) >>junk.c

@@ -459,7 +459,7 @@
 echo.

 echo Configure failed.

 echo To configure Emacs for Windows, you need to have either

-echo gcc-2.95 or later with Mingw32 and the W32 API headers,

+echo gcc-2.95 or later with Mingw32 and the Windows API headers,

 echo or MSVC 2.x or later.

 del junk.c

 goto end


=== modified file 'nt/makefile.w32-in'
--- nt/makefile.w32-in  2011-11-30 16:23:05 +0000
+++ nt/makefile.w32-in  2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-# -*- Makefile -*- for GNU Emacs on the Microsoft W32 API.

+# -*- Makefile -*- for GNU Emacs on the Microsoft Windows API.

 # Copyright (C) 2000-2011 Free Software Foundation, Inc.

 #

 # Top level makefile for building GNU Emacs on Windows NT


=== modified file 'src/ChangeLog'
--- src/ChangeLog       2012-01-02 06:41:42 +0000
+++ src/ChangeLog       2012-01-02 08:44:52 +0000
@@ -1,6 +1,6 @@
 2012-01-02  Paul Eggert  <eggert@cs.ucla.edu>
 
-       Don't use the abbreviation "win" to refer to Windows.
+       Don't use the abbreviation "win" to refer to Windows (Bug#10421).
        * regex.c (MAX_BUF_SIZE): Remove some incorrect and
        long-ago-commented-out code that talks about "WIN32".
        * w32heap.h (OS_WINDOWS_95): Rename from OS_WIN95.

=== modified file 'src/ChangeLog.10'
--- src/ChangeLog.10    2012-01-02 06:41:42 +0000
+++ src/ChangeLog.10    2012-01-02 08:44:52 +0000
@@ -15825,7 +15825,7 @@
        * w32term.c (w32_draw_fringe_bitmap): Copy unadapted code from
        xterm.c to handle overlaid fringe bitmaps and to use cursor color
        for displaying cursor in fringe.
-       (w32_define_fringe_bitmap, w32_destroy_fringe_bitmap): New W32
+       (w32_define_fringe_bitmap, w32_destroy_fringe_bitmap): New Windows
        specific functions to define and destroy fringe bitmaps in fringe_bmp.
        (w32_redisplay_interface): Add them to redisplay_interface.
        (w32_term_init): Call w32_init_fringe instead of explicitly
@@ -21476,7 +21476,7 @@
        "Emacs built on Windows 9x/ME crashes at startup on Windows XP,
        or Emacs builtpart of on XP crashes at startup on Windows 9x/ME."
 
-       * w32.c: Added wrapper functions around the w32 API functions
+       * w32.c: Added wrapper functions around the Windows API functions
        OpenProcessToken, GetTokenInformation, LookupAccountSid, and
        GetSidIdentifierAuthority.  These wrapper functions serve two
        purposes:
@@ -21490,7 +21490,7 @@
        the version of advapi32.dll that is found in the 9x branch of
        Microsoft Windows.
 
-       * w32.c (init_user_info): Replace the calls to the w32 API
+       * w32.c (init_user_info): Replace the calls to the Windows API
        functions OpenProcessToken, GetTokenInformation, LookupAccountSid,
        and GetSidIdentifierAuthority with calls to the newly added
        wrapper functions.

=== modified file 'src/ChangeLog.11'
--- src/ChangeLog.11    2011-12-19 15:46:50 +0000
+++ src/ChangeLog.11    2012-01-02 08:44:52 +0000
@@ -3995,7 +3995,8 @@
 
 2010-09-24  Juanma Barranquero  <lekktu@gmail.com>
 
-       Remove W32 API function pointer unused since 2005-02-15 (revno 60055).
+       Remove Windows API function pointer unused since 2005-02-15 (revno
+       60055).
        * w32fns.c (clipboard_sequence_fn): Don't declare.
        (globals_of_w32fns): Don't initialize it.
 

=== modified file 'src/ChangeLog.8'
--- src/ChangeLog.8     2011-12-15 07:24:10 +0000
+++ src/ChangeLog.8     2012-01-02 08:44:52 +0000
@@ -13203,7 +13203,7 @@
        * w32.c (stat): GetFileInformationByHandle can legitimately fail,
        so don't rely on it succeeding.
 
-       * w32fns.c (x_to_w32_font): Specify DEFAULT_CHARSET in the w32
+       * w32fns.c (x_to_w32_font): Specify DEFAULT_CHARSET in the Windows
        LOGFONT struct if x font doesn't specify the charset.
        (x_to_w32_charset): Change >= to == when testing results of
        stricmp.

=== modified file 'src/makefile.w32-in'
--- src/makefile.w32-in 2011-11-12 12:11:54 +0000
+++ src/makefile.w32-in 2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-# -*- Makefile -*- for GNU Emacs on the Microsoft W32 API.
+# -*- Makefile -*- for GNU Emacs on the Microsoft Windows API.
 # Copyright (C) 2000-2011  Free Software Foundation, Inc.
 
 # This file is part of GNU Emacs.

=== modified file 'src/sound.c'
--- src/sound.c 2012-01-02 06:41:42 +0000
+++ src/sound.c 2012-01-02 08:44:52 +0000
@@ -30,7 +30,7 @@
   cause an error to be generated.
 
   The Windows implementation of play-sound is implemented via the
-  w32 API functions mciSendString, waveOutGetVolume, and
+  Windows API functions mciSendString, waveOutGetVolume, and
   waveOutSetVolume which are exported by Winmm.dll.
 */
 

=== modified file 'src/w32.c'
--- src/w32.c   2012-01-02 06:41:42 +0000
+++ src/w32.c   2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Utility and Unix shadow routines for GNU Emacs on the Microsoft W32 API.
+/* Utility and Unix shadow routines for GNU Emacs on the Microsoft Windows API.
    Copyright (C) 1994-1995, 2000-2011  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -2006,7 +2006,7 @@
 }
 
 /* ------------------------------------------------------------------------- */
-/* IO support and wrapper functions for W32 API. */
+/* IO support and wrapper functions for the Windows API. */
 /* ------------------------------------------------------------------------- */
 
 /* Place a wrapper around the MSVC version of ctime.  It returns NULL

=== modified file 'src/w32console.c'
--- src/w32console.c    2012-01-02 06:41:42 +0000
+++ src/w32console.c    2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Terminal hooks for GNU Emacs on the Microsoft W32 API.
+/* Terminal hooks for GNU Emacs on the Microsoft Windows API.
    Copyright (C) 1992, 1999, 2001-2011  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.

=== modified file 'src/w32fns.c'
--- src/w32font.h       2011-11-16 17:47:25 +0000
+++ src/w32font.h       2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Shared GDI and Uniscribe Font backend declarations for the W32 API.
+/* Shared GDI and Uniscribe Font backend declarations for the Windows API.
    Copyright (C) 2007-2011 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.

=== modified file 'src/w32gui.h'
--- src/w32gui.h        2011-05-14 09:03:53 +0000
+++ src/w32gui.h        2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Definitions and headers for communication on the Microsoft W32 API.
+/* Definitions and headers for communication on the Microsoft Windows API.
    Copyright (C) 1995, 2001-2011  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.

=== modified file 'src/w32heap.c'
--- src/w32heap.c       2012-01-02 06:41:42 +0000
+++ src/w32heap.c       2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Heap management routines for GNU Emacs on the Microsoft W32 API.
+/* Heap management routines for GNU Emacs on the Microsoft Windows API.
    Copyright (C) 1994, 2001-2011  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.

=== modified file 'src/w32inevt.c'
--- src/w32inevt.c      2011-05-14 19:06:08 +0000
+++ src/w32inevt.c      2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Input event support for Emacs on the Microsoft W32 API.
+/* Input event support for Emacs on the Microsoft Windows API.
    Copyright (C) 1992-1993, 1995, 2001-2011  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.

=== modified file 'src/w32inevt.h'
--- src/w32inevt.h      2011-01-25 04:08:28 +0000
+++ src/w32inevt.h      2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Input routines for GNU Emacs on the Microsoft W32 API.
+/* Input routines for GNU Emacs on the Microsoft Windows API.
    Copyright (C) 1995, 2001-2011  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -28,4 +28,3 @@
                                        unsigned long *time);
 
 #endif /* EMACS_W32INEVT_H */
-

=== modified file 'src/w32menu.c'
--- src/w32menu.c       2011-11-20 19:35:27 +0000
+++ src/w32menu.c       2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Menu support for GNU Emacs on the Microsoft W32 API.
+/* Menu support for GNU Emacs on the Microsoft Windows API.
    Copyright (C) 1986, 1988, 1993-1994, 1996, 1998-1999, 2001-2011
                  Free Software Foundation, Inc.
 

=== modified file 'src/w32proc.c'
--- src/w32proc.c       2012-01-02 06:41:42 +0000
+++ src/w32proc.c       2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Process support for GNU Emacs on the Microsoft W32 API.
+/* Process support for GNU Emacs on the Microsoft Windows API.
    Copyright (C) 1992, 1995, 1999-2011  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -781,7 +781,7 @@
   unixtodos_filename (cmdname);
   argv[0] = cmdname;
 
-  /* Determine whether program is a 16-bit DOS executable, or a w32
+  /* Determine whether program is a 16-bit DOS executable, or a 32-bit Windows
      executable that is implicitly linked to the Cygnus dll (implying it
      was compiled with the Cygnus GNU toolchain and hence relies on
      cygwin.dll to parse the command line - we use this to decide how to

=== modified file 'src/w32select.c'
--- src/w32select.c     2011-12-05 08:55:25 +0000
+++ src/w32select.c     2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Selection processing for Emacs on the Microsoft W32 API.
+/* Selection processing for Emacs on the Microsoft Windows API.
 
 Copyright (C) 1993-1994, 2001-2011  Free Software Foundation, Inc.
 

=== modified file 'src/w32term.c'
--- src/w32term.c       2011-12-30 02:52:49 +0000
+++ src/w32term.c       2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Implementation of GUI terminal on the Microsoft W32 API.
+/* Implementation of GUI terminal on the Microsoft Windows API.
 
 Copyright (C) 1989, 1993-2011  Free Software Foundation, Inc.
 

=== modified file 'src/w32term.h'
--- src/w32term.h       2011-12-04 08:02:42 +0000
+++ src/w32term.h       2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Definitions and headers for communication on the Microsoft W32 API.
+/* Definitions and headers for communication on the Microsoft Windows API.
    Copyright (C) 1995, 2001-2011 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.

=== modified file 'src/w32xfns.c'
--- src/w32xfns.c       2011-11-20 02:29:42 +0000
+++ src/w32xfns.c       2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
-/* Functions taken directly from X sources for use with the Microsoft W32 API.
+/* Functions taken directly from X sources for use with the Microsoft Windows 
API.
    Copyright (C) 1989, 1992-1995, 1999, 2001-2011  Free Software Foundation, 
Inc.
 
 This file is part of GNU Emacs.

Attachment: total-patch.txt.gz
Description: GNU Zip compressed data


reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- src/w32fns.c        2012-01-02 06:41:42 +0000
+++ src/w32fns.c        2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
 /* Graphical user interface functions for the Microsoft W32 API.
 
 Copyright (C) 1989, 1992-2011  Free Software Foundation, Inc.
 
@@ -6598,7 +6598,7 @@
   value = Qnil;
 
   /* Determining the required information on Windows turns out, sadly,
-     to be more involved than one would hope.  The original w32 api
+     to be more involved than one would hope.  The original Windows API
      call for this will return bogus information on some systems, but we
      must dynamically probe for the replacement api, since that was
      added rather late on.  */
@@ -1,4 +1,4 @@
-/* Graphical user interface functions for the Microsoft W32 API.
+/* Graphical user interface functions for the Microsoft Windows API.
 
 Copyright (C) 1989, 1992-2011  Free Software Foundation, Inc.

=== modified file 'src/w32font.c'
--- src/w32font.c       2011-12-15 07:24:10 +0000
+++ src/w32font.c       2012-01-02 08:44:52 +0000
@@ -1,4 +1,4 @@
 /* Font backend for the Microsoft W32 API.
    Copyright (C) 2007-2011 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -1404,7 +1404,7 @@
                    currently appear in fontset.el, so it isn't worth
                    creating a mapping table of codepages/scripts to languages
                    or opening the font to see if there are any language tags
-                   in it that the W32 API does not expose. Fontset
+                   in it that the Windows API does not expose. Fontset
                   spec should have a fallback, as some backends do
                   not recognize language at all.  */
                return 0;
@@ -1,4 +1,4 @@
-/* Font backend for the Microsoft W32 API.
+/* Font backend for the Microsoft Windows API.
    Copyright (C) 2007-2011 Free Software Foundation, Inc.
 

=== modified file 'src/w32font.h'